@@ -1,12 +1,12 @@
-from threedi_api_client import ThreediApiClient
+from threedi_api_client.threedi_api_client import ThreediApiClient
 
 
 def test_init_threedi_api_client_from_env_file(tmpdir):
     env_file = tmpdir / 'env_file'
     with open(str(env_file), 'w') as f:
-        f.write("API_HOST=localhost:8000/v3.0")
-        f.write("API_USERNAME=username")
-        f.write("API_PASSWORD=password")
+        f.write("API_HOST=localhost:8000/v3.0\n")
+        f.write("API_USERNAME=username\n")
+        f.write("API_PASSWORD=password\n")
     ThreediApiClient(env_file=str(env_file))
 
 
